@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from flake8.api import legacy as engine
+from flake8 import engine
 import pycodestyle
 
 import hacking.tests
@@ -28,14 +28,9 @@ def check(physical_line):
 class HackingTestCase(hacking.tests.TestCase):
     def test_local_check(self):
         flake8_style = engine.get_style_guide(parse_argv=False, ignore='F')
-        self.options.benchmark_keys = pycodestyle.BENCHMARK_KEYS
-        self.options.ignore_code = pycodestyle.StyleGuide.ignore_code
-        self.options.physical_checks = []
-        self.options.logical_checks = []
-        self.options.ast_checks = []
         report = pycodestyle.BaseReport(flake8_style.options)
         line = ["#this-is-the-test-phrase"]
         checker = pycodestyle.Checker(lines=line, options=flake8_style.options,
-                               report=report)
+                                      report=report)
         checker.check_all()
         self.assertIn("L100", report.counters)
